# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""SWIG wrapper for the CGAL 2D Voronoi Diagram Adaptor package provided under the GPL-3.0+ license"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _CGAL_Voronoi_diagram_2
else:
    import _CGAL_Voronoi_diagram_2

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import CGAL.CGAL_Kernel
import CGAL.CGAL_Triangulation_2
class Voronoi_diagram_2_Vertex_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Vertex_handle())

    def halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_halfedge(self, *args)

    def degree(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_degree(self)

    def point(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_point(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_dual(self, *args)

    def site(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_site(self, *args)

    def is_incident_edge(self, c):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_is_incident_edge(self, c)

    def is_incident_face(self, c):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_is_incident_face(self, c)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_is_valid(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle___ne__(self, p)

    def __hash__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle___hash__(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Vertex_handle

# Register Voronoi_diagram_2_Vertex_handle in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_swigregister(Voronoi_diagram_2_Vertex_handle)

class Voronoi_diagram_2_Face_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Face_handle())

    def halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_halfedge(self, *args)

    def outer_ccb(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_outer_ccb(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_dual(self, *args)

    def is_unbounded(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_is_unbounded(self)

    def is_halfedge_on_ccb(self, c):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_is_halfedge_on_ccb(self, c)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_is_valid(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle___ne__(self, p)

    def __hash__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle___hash__(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Face_handle

# Register Voronoi_diagram_2_Face_handle in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_swigregister(Voronoi_diagram_2_Face_handle)

class Voronoi_diagram_2_Halfedge_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Halfedge_handle())

    def twin(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_twin(self, *args)

    def opposite(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_opposite(self, *args)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_next(self, *args)

    def previous(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_previous(self, *args)

    def face(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_face(self, *args)

    def source(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_source(self, *args)

    def target(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_target(self, *args)

    def ccb(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_ccb(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_dual(self, *args)

    def up(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_up(self, *args)

    def down(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_down(self, *args)

    def left(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_left(self, *args)

    def right(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_right(self, *args)

    def has_source(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_has_source(self)

    def has_target(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_has_target(self)

    def is_unbounded(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_is_unbounded(self)

    def is_bisector(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_is_bisector(self)

    def is_segment(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_is_segment(self)

    def is_ray(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_is_ray(self)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_is_valid(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle___ne__(self, p)

    def __hash__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle___hash__(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Halfedge_handle

# Register Voronoi_diagram_2_Halfedge_handle in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_swigregister(Voronoi_diagram_2_Halfedge_handle)

class Voronoi_diagram_2_Face_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Face_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Face_iterator

# Register Voronoi_diagram_2_Face_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator_swigregister(Voronoi_diagram_2_Face_iterator)

class Voronoi_diagram_2_Bounded_faces_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Bounded_faces_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Bounded_faces_iterator

# Register Voronoi_diagram_2_Bounded_faces_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator_swigregister(Voronoi_diagram_2_Bounded_faces_iterator)

class Voronoi_diagram_2_Unbounded_faces_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Unbounded_faces_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Unbounded_faces_iterator

# Register Voronoi_diagram_2_Unbounded_faces_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator_swigregister(Voronoi_diagram_2_Unbounded_faces_iterator)

class Voronoi_diagram_2_Edge_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Edge_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Edge_iterator

# Register Voronoi_diagram_2_Edge_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator_swigregister(Voronoi_diagram_2_Edge_iterator)

class Voronoi_diagram_2_Halfedge_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Halfedge_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Halfedge_iterator

# Register Voronoi_diagram_2_Halfedge_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator_swigregister(Voronoi_diagram_2_Halfedge_iterator)

class Voronoi_diagram_2_Unbounded_halfedges_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Unbounded_halfedges_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Unbounded_halfedges_iterator

# Register Voronoi_diagram_2_Unbounded_halfedges_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator_swigregister(Voronoi_diagram_2_Unbounded_halfedges_iterator)

class Voronoi_diagram_2_Bounded_halfedges_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Bounded_halfedges_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Bounded_halfedges_iterator

# Register Voronoi_diagram_2_Bounded_halfedges_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator_swigregister(Voronoi_diagram_2_Bounded_halfedges_iterator)

class Voronoi_diagram_2_Ccb_halfedge_circulator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Ccb_halfedge_circulator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator___iter__(self)

    def next(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator_next(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator_deepcopy(self, *args)

    def prev(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator_prev(self)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Ccb_halfedge_circulator

# Register Voronoi_diagram_2_Ccb_halfedge_circulator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator_swigregister(Voronoi_diagram_2_Ccb_halfedge_circulator)

class Voronoi_diagram_2_Halfedge_around_vertex_circulator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Halfedge_around_vertex_circulator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator___iter__(self)

    def next(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator_next(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator_deepcopy(self, *args)

    def prev(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator_prev(self)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Halfedge_around_vertex_circulator

# Register Voronoi_diagram_2_Halfedge_around_vertex_circulator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator_swigregister(Voronoi_diagram_2_Halfedge_around_vertex_circulator)

class Voronoi_diagram_2_Vertex_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Vertex_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Vertex_iterator

# Register Voronoi_diagram_2_Vertex_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator_swigregister(Voronoi_diagram_2_Vertex_iterator)

class Voronoi_diagram_2_Site_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Site_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Site_iterator

# Register Voronoi_diagram_2_Site_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator_swigregister(Voronoi_diagram_2_Site_iterator)

class Voronoi_diagram_2_Locate_result(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Locate_result_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Locate_result())

    def get_vertex_handle(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Locate_result_get_vertex_handle(self)

    def get_halfedge_handle(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Locate_result_get_halfedge_handle(self)

    def get_face_handle(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Locate_result_get_face_handle(self)

    def is_vertex_handle(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Locate_result_is_vertex_handle(self)

    def is_halfedge_handle(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Locate_result_is_halfedge_handle(self)

    def is_face_handle(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Locate_result_is_face_handle(self)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Locate_result

# Register Voronoi_diagram_2_Locate_result in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Locate_result_swigregister(Voronoi_diagram_2_Locate_result)

class Voronoi_diagram_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2(*args))

    def insert(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_insert(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_dual(self, *args)

    def number_of_vertices(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_number_of_vertices(self)

    def number_of_faces(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_number_of_faces(self)

    def number_of_halfedges(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_number_of_halfedges(self)

    def number_of_connected_components(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_number_of_connected_components(self)

    def unbounded_face(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_unbounded_face(self, *args)

    def bounded_face(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_bounded_face(self, *args)

    def unbounded_halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_unbounded_halfedge(self, *args)

    def bounded_halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_bounded_halfedge(self, *args)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_is_valid(self)

    def clear(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_clear(self)

    def swap(self, other):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_swap(self, other)

    def file_output(self, fname):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_file_output(self, fname)

    def file_input(self, fname):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_file_input(self, fname)

    def faces(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_faces(self)

    def unbounded_faces(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_unbounded_faces(self)

    def bounded_faces(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_bounded_faces(self)

    def edges(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_edges(self)

    def halfedges(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_halfedges(self)

    def unbounded_halfedges(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_unbounded_halfedges(self)

    def bounded_halfedges(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_bounded_halfedges(self)

    def vertices(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_vertices(self)

    def sites(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_sites(self)

    def ccb_halfedges(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_ccb_halfedges(self, *args)

    def incident_halfedges(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_incident_halfedges(self, *args)

    def locate(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_locate(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2

# Register Voronoi_diagram_2 in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_swigregister(Voronoi_diagram_2)

class Power_diagram_2_Vertex_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Vertex_handle())

    def halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_halfedge(self, *args)

    def degree(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_degree(self)

    def point(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_point(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_dual(self, *args)

    def site(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_site(self, *args)

    def is_incident_edge(self, c):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_is_incident_edge(self, c)

    def is_incident_face(self, c):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_is_incident_face(self, c)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_is_valid(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle___ne__(self, p)

    def __hash__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle___hash__(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Vertex_handle

# Register Power_diagram_2_Vertex_handle in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_swigregister(Power_diagram_2_Vertex_handle)

class Power_diagram_2_Face_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Face_handle())

    def halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_halfedge(self, *args)

    def outer_ccb(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_outer_ccb(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_dual(self, *args)

    def is_unbounded(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_is_unbounded(self)

    def is_halfedge_on_ccb(self, c):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_is_halfedge_on_ccb(self, c)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_is_valid(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle___ne__(self, p)

    def __hash__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle___hash__(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Face_handle

# Register Power_diagram_2_Face_handle in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_swigregister(Power_diagram_2_Face_handle)

class Power_diagram_2_Halfedge_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Halfedge_handle())

    def twin(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_twin(self, *args)

    def opposite(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_opposite(self, *args)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_next(self, *args)

    def previous(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_previous(self, *args)

    def face(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_face(self, *args)

    def source(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_source(self, *args)

    def target(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_target(self, *args)

    def ccb(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_ccb(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_dual(self, *args)

    def up(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_up(self, *args)

    def down(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_down(self, *args)

    def left(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_left(self, *args)

    def right(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_right(self, *args)

    def has_source(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_has_source(self)

    def has_target(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_has_target(self)

    def is_unbounded(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_is_unbounded(self)

    def is_bisector(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_is_bisector(self)

    def is_segment(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_is_segment(self)

    def is_ray(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_is_ray(self)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_is_valid(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle___ne__(self, p)

    def __hash__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle___hash__(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Halfedge_handle

# Register Power_diagram_2_Halfedge_handle in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_swigregister(Power_diagram_2_Halfedge_handle)

class Power_diagram_2_Face_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Face_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Face_iterator

# Register Power_diagram_2_Face_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator_swigregister(Power_diagram_2_Face_iterator)

class Power_diagram_2_Bounded_faces_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Bounded_faces_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Bounded_faces_iterator

# Register Power_diagram_2_Bounded_faces_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator_swigregister(Power_diagram_2_Bounded_faces_iterator)

class Power_diagram_2_Unbounded_faces_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Unbounded_faces_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Unbounded_faces_iterator

# Register Power_diagram_2_Unbounded_faces_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator_swigregister(Power_diagram_2_Unbounded_faces_iterator)

class Power_diagram_2_Edge_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Edge_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Edge_iterator

# Register Power_diagram_2_Edge_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator_swigregister(Power_diagram_2_Edge_iterator)

class Power_diagram_2_Halfedge_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Halfedge_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Halfedge_iterator

# Register Power_diagram_2_Halfedge_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator_swigregister(Power_diagram_2_Halfedge_iterator)

class Power_diagram_2_Unbounded_halfedges_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Unbounded_halfedges_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Unbounded_halfedges_iterator

# Register Power_diagram_2_Unbounded_halfedges_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator_swigregister(Power_diagram_2_Unbounded_halfedges_iterator)

class Power_diagram_2_Bounded_halfedges_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Bounded_halfedges_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Bounded_halfedges_iterator

# Register Power_diagram_2_Bounded_halfedges_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator_swigregister(Power_diagram_2_Bounded_halfedges_iterator)

class Power_diagram_2_Ccb_halfedge_circulator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Ccb_halfedge_circulator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator___iter__(self)

    def next(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator_next(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator_deepcopy(self, *args)

    def prev(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator_prev(self)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Ccb_halfedge_circulator

# Register Power_diagram_2_Ccb_halfedge_circulator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator_swigregister(Power_diagram_2_Ccb_halfedge_circulator)

class Power_diagram_2_Halfedge_around_vertex_circulator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Halfedge_around_vertex_circulator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator___iter__(self)

    def next(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator_next(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator_deepcopy(self, *args)

    def prev(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator_prev(self)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Halfedge_around_vertex_circulator

# Register Power_diagram_2_Halfedge_around_vertex_circulator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator_swigregister(Power_diagram_2_Halfedge_around_vertex_circulator)

class Power_diagram_2_Vertex_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Vertex_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Vertex_iterator

# Register Power_diagram_2_Vertex_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator_swigregister(Power_diagram_2_Vertex_iterator)

class Power_diagram_2_Site_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Site_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Site_iterator

# Register Power_diagram_2_Site_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator_swigregister(Power_diagram_2_Site_iterator)

class Power_diagram_2_Locate_result(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Locate_result_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Locate_result())

    def get_vertex_handle(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Locate_result_get_vertex_handle(self)

    def get_halfedge_handle(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Locate_result_get_halfedge_handle(self)

    def get_face_handle(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Locate_result_get_face_handle(self)

    def is_vertex_handle(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Locate_result_is_vertex_handle(self)

    def is_halfedge_handle(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Locate_result_is_halfedge_handle(self)

    def is_face_handle(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Locate_result_is_face_handle(self)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Locate_result

# Register Power_diagram_2_Locate_result in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Locate_result_swigregister(Power_diagram_2_Locate_result)

class Power_diagram_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2(*args))

    def insert(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_insert(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_dual(self, *args)

    def number_of_vertices(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_number_of_vertices(self)

    def number_of_faces(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_number_of_faces(self)

    def number_of_halfedges(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_number_of_halfedges(self)

    def number_of_connected_components(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_number_of_connected_components(self)

    def unbounded_face(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_unbounded_face(self, *args)

    def bounded_face(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_bounded_face(self, *args)

    def unbounded_halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_unbounded_halfedge(self, *args)

    def bounded_halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_bounded_halfedge(self, *args)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_is_valid(self)

    def clear(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_clear(self)

    def swap(self, other):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_swap(self, other)

    def file_output(self, fname):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_file_output(self, fname)

    def file_input(self, fname):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_file_input(self, fname)

    def faces(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_faces(self)

    def unbounded_faces(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_unbounded_faces(self)

    def bounded_faces(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_bounded_faces(self)

    def edges(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_edges(self)

    def halfedges(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_halfedges(self)

    def unbounded_halfedges(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_unbounded_halfedges(self)

    def bounded_halfedges(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_bounded_halfedges(self)

    def vertices(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_vertices(self)

    def sites(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_sites(self)

    def ccb_halfedges(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_ccb_halfedges(self, *args)

    def incident_halfedges(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_incident_halfedges(self, *args)

    def locate(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_locate(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2

# Register Power_diagram_2 in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_swigregister(Power_diagram_2)


def crop_voronoi_facet(arg1, arg2, arg3, arg4):
    return _CGAL_Voronoi_diagram_2.crop_voronoi_facet(arg1, arg2, arg3, arg4)
class Optional_segment_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Optional_segment_2_swiginit(self, _CGAL_Voronoi_diagram_2.new_Optional_segment_2())

    def empty(self):
        return _CGAL_Voronoi_diagram_2.Optional_segment_2_empty(self)

    def value(self):
        return _CGAL_Voronoi_diagram_2.Optional_segment_2_value(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Optional_segment_2_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Optional_segment_2

# Register Optional_segment_2 in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Optional_segment_2_swigregister(Optional_segment_2)


def crop_voronoi_facet_polygon(arg1, arg2, arg3, arg4):
    return _CGAL_Voronoi_diagram_2.crop_voronoi_facet_polygon(arg1, arg2, arg3, arg4)

def crop_voronoi_edge(arg1, arg2, arg3):
    return _CGAL_Voronoi_diagram_2.crop_voronoi_edge(arg1, arg2, arg3)


